========
Vaxadium
========


.. image:: https://img.shields.io/pypi/v/vaxadium.svg
        :target: https://pypi.python.org/pypi/vaxadium

.. image:: https://github.com/DiamondLightSource/vaxadium/actions/workflows/deploy-release.yml/badge.svg
        :target: https://github.com/DiamondLightSource/vaxadium/actions/workflows/deploy-release.yml)


Vaxadium uses simulations to normalise x-ray scattering data. 


* Free software: BSD license
* Documentation: https://DiamondLightSource.github.io/vaxadium/


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
